@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * gtkperiodic.c 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -23,6 +23,9 @@
  */
 
 #include "config.h"
+#warning "the following lines should be removed for stable releases"
+#undef PACKAGE
+#define PACKAGE "gchemutils-unstable" 
 #include "gtkperiodic.h"
 #include "chemistry.h"
 #include <string.h>
@@ -163,7 +166,7 @@ void gtk_periodic_init (GtkPeriodic *periodic)
 	int i;
 	char* domain = g_strdup(textdomain(NULL));
 	textdomain(GETTEXT_PACKAGE);
-	xml =  glade_xml_new(DATADIR"/gchemutils/glade/gtkperiodic.glade", "vbox1", NULL);
+	xml =  glade_xml_new(DATADIR"/"PACKAGE"/glade/gtkperiodic.glade", "vbox1", NULL);
 	g_return_if_fail (xml);
 	g_object_set_data(G_OBJECT(periodic), "xml", xml);
 	glade_xml_signal_autoconnect (xml);
@@ -263,7 +266,7 @@ void gtk_periodic_size_request(GtkPeriodic* w, GtkRequisition *requisition)
 
 guint gtk_periodic_get_element(GtkPeriodic* periodic)
 {
-	g_return_if_fail(GTK_IS_PERIODIC(periodic));
+	g_return_val_if_fail(GTK_IS_PERIODIC(periodic), 0);
 	return periodic->priv->Z;
 }
 
